@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: fix_template.py 12436 2020-07-30 08:41:42Z Lavender $
+# $Id: fix_template.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2020-07-30 16:41:42 +0800 (週四, 30 七月 2020) $
-# $Revision: 12436 $
+# $Author: Mint $
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 import os
 import hashlib
@@ -60,7 +60,7 @@ class Command(BaseCommand):
                     # preprocess
                     loadTagHash = hashlib.md5(toBytes(
                         "{% load cms_tags menu_tags sekizai_tags %}"
-                        "{% load staticfiles %}")).hexdigest()
+                        "{% load static %}")).hexdigest()
                     jsHash = "%s" % hashlib.md5(toBytes(
                         "{% render_block 'js' %}")).hexdigest()
                     cssHash = "%s" % hashlib.md5(toBytes(
@@ -77,7 +77,7 @@ class Command(BaseCommand):
                             text = f.read()
                         
                     text = text.replace(
-                        "{% load cms_tags menu_tags sekizai_tags staticfiles %}", 
+                        "{% load cms_tags menu_tags sekizai_tags static %}", 
                         "{% load FakeTemplateTags %}" + loadTagHash)
                     text = text.replace("{% render_block 'css' %}", cssHash)
                     text = text.replace("{% render_block 'js' %}", jsHash)
@@ -102,7 +102,7 @@ class Command(BaseCommand):
                     # endprocess
                     text = text.replace(
                         loadTagHash, 
-                        ("{% load cms_tags menu_tags sekizai_tags staticfiles %}"
+                        ("{% load cms_tags menu_tags sekizai_tags static %}"
                          "{% with '' as CMS_STATIC_PREFIX %}{% with '/' as CMS_LINK_PREFIX %}"))
                     text = text.replace(
                         jsHash, "{% endwith %}{% endwith %}{% render_block 'js' %}")
