@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 12629 2020-11-26 13:42:29Z Lavender $
+# $Id: setup.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2020-11-26 21:42:29 +0800 (週四, 26 十一月 2020) $
-# $Revision: 12629 $
+# $Author: Mint $
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 import re
 import os
@@ -61,7 +61,9 @@ INTRODUCTION_URL = "https://www.django-cms-themes.com/static/docs"
 SETUP_URL = "https://www.django-cms-themes.com/static/product/assets/setup.py"
 SETUP_VERSION = "1.1.1"
 SETUP_DIR = os.path.dirname(os.path.abspath(__file__))
-SETUP_SUPPORTED_CMS_VERSION = "3.7.4"
+SETUP_SUPPORTED_CMS_VERSION = "3.9.0"
+CMS_INSTALLER_GIT_LINK = 'https://github.com/nuwainfo/djangocms-installer/archive/Zephyrus5.tar.gz'
+
 CKEDITOR_SETTINGS = \
 '''
 CKEDITOR_SETTINGS = {
@@ -106,28 +108,6 @@ SCHEMA_FIX = '''
         self.connection.cursor().execute('PRAGMA legacy_alter_table = OFF')
         self.connection.enable_constraint_checking()
 '''
-
-SCHEMA_FIX_MD5_1_11 = "08fc81f9012c4a7f94782edc030885e7"
-SCHEMA_ORIGIN_MD5_DJANGO_1_11 = "c27ea4f5a250178b0a417b719c40c3a8"
-SCHEMA_ORIGIN_DJANGO_1_11 = '''
-    def __enter__(self):
-        with self.connection.cursor() as c:
-            # Some SQLite schema alterations need foreign key constraints to be
-            # disabled. This is the default in SQLite but can be changed with a
-            # build flag and might change in future, so can't be relied upon.
-            # We enforce it here for the duration of the transaction.
-            c.execute('PRAGMA foreign_keys')
-            self._initial_pragma_fk = c.fetchone()[0]
-            c.execute('PRAGMA foreign_keys = 0')
-        return super(DatabaseSchemaEditor, self).__enter__()
-
-    def __exit__(self, exc_type, exc_value, traceback):
-        super(DatabaseSchemaEditor, self).__exit__(exc_type, exc_value, traceback)
-        with self.connection.cursor() as c:
-            # Restore initial FK setting - PRAGMA values can't be parametrized
-            c.execute('PRAGMA foreign_keys = %s' % int(self._initial_pragma_fk))
-'''
-
 SCHEMA_FIX_MD5_2_1 = "de8e3a3770fdb73b3f4478e0410ceaf9"
 SCHEMA_ORIGIN_MD5_DJANGO_2_1 = "280dba9301b0a827962786c34456ca54"
 SCHEMA_ORIGIN_DJANGO_2_1 = '''
@@ -371,15 +351,9 @@ else:
             if yesOrNo == 'yes':
                 
                 if canAddPlugin(
-                    'djangocms-history', 'djangocms_history==0.5.3'):
+                    'djangocms-history', 'djangocms_history==2.0.0'):
                     pluginList.append('djangocms_history')
-                    requirementList.append('djangocms_history==0.5.3')
-                    
-                if not django.VERSION >= (2, 0):
-                    if canAddPlugin(
-                        'djangocms-forms', 'djangocms_forms==0.2.5'):
-                        pluginList.append('djangocms_forms')
-                        requirementList.append('djangocms_forms==0.2.5')
+                    requirementList.append('djangocms_history==2.0.0')
             
             with open(os.path.join(baseDir, "requirements.txt"), 'a') as reqs:
                 reqs.write("\n")
@@ -389,13 +363,12 @@ else:
         content += "INSTALLED_APPS += %s" % str(tuple(pluginList))
         content += CKEDITOR_SETTINGS
         
-        if int(cmsVersion[0]) == 3 and int(cmsVersion[1]) == 7:
+        if int(cmsVersion[0]) == 3 and int(cmsVersion[1]) >= 7:
             content = content.replace(
                 "'djangocms_bootstrap4.contrib.bootstrap4_picture',", 
                 "#'djangocms_bootstrap4.contrib.bootstrap4_picture',")
         settings.write(content)
-           
-               
+   
     logger.info(colored("Succeed to write settings.py", "yellow"))
                
 def loadData(baseDir, language):
@@ -438,14 +411,10 @@ def fixSchema(schemaPath):
         with open(schemaPath, 'r') as f:
             content = f.read()
             
-        if not django.VERSION >= (2, 0):
-            SCHEMA_FIX_MD5 = SCHEMA_FIX_MD5_1_11
-            SCHEMA_ORIGIN = SCHEMA_ORIGIN_DJANGO_1_11 
-            SCHEMA_ORIGIN_MD5 = SCHEMA_ORIGIN_MD5_DJANGO_1_11
-        else:
-            SCHEMA_FIX_MD5 = SCHEMA_FIX_MD5_2_1
-            SCHEMA_ORIGIN = SCHEMA_ORIGIN_DJANGO_2_1
-            SCHEMA_ORIGIN_MD5 = SCHEMA_ORIGIN_MD5_DJANGO_2_1
+        
+        SCHEMA_FIX_MD5 = SCHEMA_FIX_MD5_2_1
+        SCHEMA_ORIGIN = SCHEMA_ORIGIN_DJANGO_2_1
+        SCHEMA_ORIGIN_MD5 = SCHEMA_ORIGIN_MD5_DJANGO_2_1
         
         if hashlib.md5(content.encode()).hexdigest() == SCHEMA_ORIGIN_MD5:
             content = content.replace(SCHEMA_ORIGIN, SCHEMA_FIX)
@@ -464,14 +433,10 @@ def revertSchema(schemaPath):
         with open(schemaPath, 'r') as f:
             content = f.read()
             
-        if not django.VERSION >= (2, 0):
-            SCHEMA_FIX_MD5 = SCHEMA_FIX_MD5_1_11
-            SCHEMA_ORIGIN = SCHEMA_ORIGIN_DJANGO_1_11 
-            SCHEMA_ORIGIN_MD5 = SCHEMA_ORIGIN_MD5_DJANGO_1_11
-        else:
-            SCHEMA_FIX_MD5 = SCHEMA_FIX_MD5_2_1
-            SCHEMA_ORIGIN = SCHEMA_ORIGIN_DJANGO_2_1
-            SCHEMA_ORIGIN_MD5 = SCHEMA_ORIGIN_MD5_DJANGO_2_1
+        
+        SCHEMA_FIX_MD5 = SCHEMA_FIX_MD5_2_1
+        SCHEMA_ORIGIN = SCHEMA_ORIGIN_DJANGO_2_1
+        SCHEMA_ORIGIN_MD5 = SCHEMA_ORIGIN_MD5_DJANGO_2_1
             
         if hashlib.md5(content.encode()).hexdigest() == SCHEMA_FIX_MD5:
             content = content.replace(SCHEMA_FIX, SCHEMA_ORIGIN)
@@ -492,8 +457,8 @@ if __name__ == "__main__":
         
         parser.add_argument(
             "--djangoVersion", metavar='djangoVersion', 
-            type=str,  nargs='?', default="3.0",
-            help="Django version, default is '3.0'"
+            type=str,  nargs='?', default="3.2",
+            help="Django version, default is '3.2'"
         )
         
         parser.add_argument(
@@ -533,13 +498,12 @@ if __name__ == "__main__":
         djangoVersion = args.djangoVersion
         
         djangoVersionTable = {
-            '3.0': '<3.1.0,>=3.0',
-            '2.2': '<3.0.0,>=2.2',
-            '1.11': '<2.0.0,>=1.11',
+            '3.2': '<3.3,>=3.2',
+            '2.2': '<2.3,>=2.2',
         }
         if not djangoVersion in djangoVersionTable:
             logger.warning(colored(
-                "Django version must be 1.11, 2.2 or 3.0", "yellow"))
+                "Django version must be  2.2 or 3.2", "yellow"))
             sys.exit(1)
         else:
             djangoVersion = djangoVersionTable[djangoVersion]
@@ -552,7 +516,7 @@ if __name__ == "__main__":
             if not "%d.%d" % (django.VERSION[0], django.VERSION[1]) in djangoVersionTable:
                 logger.warning(colored(
                     ("Your current Django version is %s which is not fully tested version for Django CMS themes. "
-                     "It should work, but if you encounter any problem, we recommend you switch to Django>=2.2,<2.3") % 
+                     "It should work, but if you encounter any problem, we recommend you switch to Django>=3.2,<3.3") % 
                      djangoVersion, 
                     "yellow", attrs=['bold'])
                 )
@@ -586,15 +550,17 @@ if __name__ == "__main__":
                 
             cmsVersion = data["DjangoCMSVersion"]
         else:
-            cmsVersion = '3.7.4'
+            cmsVersion = '3.9.0'
             
         # default for setup.py
-        cmsVersion = '3.7.4'
+        cmsVersion = '3.9.0'
         
         if cmsVersion.startswith("3.6"):
             installVersion = "1.2.0"
         elif cmsVersion.startswith("3.7"):
             installVersion = "1.2.3"
+        elif cmsVersion.startswith("3.9"):
+            installVersion = "github"
         else:
             logger.warning(colored(
                 "Not support django-cms<3.6", "yellow"))
@@ -621,27 +587,14 @@ if __name__ == "__main__":
         cmsVersion = cms.__version__
         
         # check package version
-        if django.VERSION <= (2, 0): 
-            try:
-                os.system(
-                    "pip install -U djangocms_text_ckeditor==3.8.0 --no-deps")
-                os.system(
-                    "pip install -U html5lib==1.0.1 --no-deps")
-                os.system("pip install cmsplugin-filer==1.1.3")
-            except Exception as e:
-                logger.error(
-                    colored("Can't install djangocms_text_ckeditor==3.8.0", 
-                            "red"))
-                sys.exit(1)
-        else:
-            try:
-                os.system(
-                    "pip install -U djangocms_text_ckeditor==3.10.0 --no-deps")
-            except Exception as e:
-                logger.error(
-                    colored("Can't install djangocms_text_ckeditor==3.10.0", 
-                            "red"))
-                sys.exit(1)
+        try:
+            os.system(
+                "pip install -U djangocms_text_ckeditor==3.10.0 --no-deps")
+        except Exception as e:
+            logger.error(
+                colored("Can't install djangocms_text_ckeditor==3.10.0", 
+                        "red"))
+            sys.exit(1)
             
         sendLog({
             "level": "INFO",
@@ -673,10 +626,14 @@ if __name__ == "__main__":
                         ("Django project not found. "
                          "Auto create one by djangocms-installer==%s."
                          "\nPlease input a project name:") % installVersion)
-            
-            result = os.system(
-                "pip install djangocms-installer==%s" % installVersion)
-                
+            # change to current version
+            if installVersion == "github":
+            	result = os.system(
+                    "pip install %s" % CMS_INSTALLER_GIT_LINK)
+            else:
+                result = os.system(
+                	"pip install djangocms-installer==%s" % installVersion)
+                    
             if schemaPath:
                 # modify django schema.py
                 logger.warning(colored(
