@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11593 2019-05-29 06:23:49Z Lavender $
+# $Id: cms_plugins.py 13402 2022-04-05 17:29:36Z Jacky $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2019-05-29 14:23:49 +0800 (Wed, 29 May 2019) $
-# $Revision: 11593 $
+# $Author: Jacky $
+# $Date: 2022-04-06 01:29:36 +0800 (週三, 06 四月 2022) $
+# $Revision: 13402 $
 
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
@@ -34,8 +34,8 @@ class CMSCommentPlugin(CMSPluginBase):
     def get_render_template(self, context, instance, placeholder):
         return select_template([
             instance.renderTemplate,
-            _settings.ZEPHYRUS_COMMENT_TEMPLATES,
-        ])
+        ] + [template[0] for template in _settings.ZEPHYRUS_COMMENT_TEMPLATES]
+        )
 
     def render(self, context, instance, placeholder):
         request = context['request']
@@ -49,7 +49,7 @@ class CMSCommentPlugin(CMSPluginBase):
         )
         obj.useFbComment = instance.useFbComment
         obj.save()
-        
+
         context.update({
             'plugin': instance,
             'url': url,
@@ -72,12 +72,12 @@ class CMSRecentResponsePlugin(CMSPluginBase):
 
     def render(self, context, instance, placeholder):
         comments = Comment.objects.order_by('-createDate')
-        
+
         if comments.count() >= instance.limit:
             comments = comments[:instance.limit]
         else:
             comments = comments
-            
+
         context.update({
             'comments': comments,
         })
