@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 13082 2021-07-20 09:02:16Z Mint $
+# $Id: urls.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Mint $
-# $Date: 2021-07-20 17:02:16 +0800 (Tue, 20 Jul 2021) $
-# $Revision: 13082 $ 
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $ 
 
 from django.conf.urls import url
 from django.urls import include, path
@@ -27,5 +27,7 @@ urlpatterns = [
     url(r'^comments/(?P<pk>\d+)/hide$', 
         views.CommentHideView.as_view(), name='hideComment'),
     # 此處修改請見 https://code.nuwainfo.com/trac/mercurius/ticket/3545#comment:7
-    path('captcha/$', include('captcha.urls')),        
+    #path('captcha/$', include('captcha.urls')), 
+    path('captcha/', include('captcha.urls')),        
+    
 ]
