@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12357 2020-06-18 00:42:10Z Lavender $
+# $Id: __init__.py 13223 2021-08-11 15:06:37Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-06-18 08:42:10 +0800 (週四, 18 六月 2020) $
-# $Revision: 12357 $
+# $Date: 2021-08-11 23:06:37 +0800 (週三, 11 八月 2021) $
+# $Revision: 13223 $
 
 import json
 import requests
@@ -41,6 +41,11 @@ class Settings(object):
     ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID = "1435073943305111"
     ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET = "1f0ba7a626695ee0c5419627c2d0a8b9"
     ZEPHYRUS_FACEBOOK_WEBHOOK_VERIFY_TOKEN = "25025529"
+    ZEPHYRUS_FACEBOOK_PROXY = { 
+        "http": "http://Nuwa:25025529@35.229.140.3:8888/", 
+        "https": "http://Nuwa:25025529@35.229.140.3:8888/", 
+    }
+    
     
     ZEPHYRUS_FACEBOOK_FAN_DEFAULT_TEMPLATE = \
         "facebook/FacebookFanPlugin.html"
