@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 13272 2021-08-24 05:47:26Z Casey $
+# $Id: cms_plugins.py 13373 2022-01-10 07:18:23Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Casey $
-# $Date: 2021-08-24 13:47:26 +0800 (週二, 24 八月 2021) $
-# $Revision: 13272 $
+# $Author: Lavender $
+# $Date: 2022-01-10 15:18:23 +0800 (週一, 10 一月 2022) $
+# $Revision: 13373 $
 
 import re
 import requests
@@ -119,8 +119,10 @@ def getFanPageId(accessToken, url):
 def getFanPage(url, limit):
     try:
         # get data
+        # req = requests.get(
+            # "%sposts/?ref=page_internal&_fb_noscript=1" % url, proxies=zephyrusSettings.ZEPHYRUS_FACEBOOK_PROXY)  
         req = requests.get(
-            "%sposts/?ref=page_internal&_fb_noscript=1" % url, proxies=zephyrusSettings.ZEPHYRUS_FACEBOOK_PROXY)  
+            "%sposts/?ref=page_internal&_fb_noscript=1" % url)
         content = req.text
         soup = BeautifulSoup(content, 'html.parser')
         
