@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11898 2020-02-04 18:28:40Z Lavender $
+# $Id: models.py 13421 2022-04-19 08:37:17Z Jacky $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2020-02-05 02:28:40 +0800 (Wed, 05 Feb 2020) $
-# $Revision: 11898 $
+# $Author: Jacky $
+# $Date: 2022-04-19 16:37:17 +0800 (週二, 19 四月 2022) $
+# $Revision: 13421 $
 
 
 from django.db import models
@@ -32,11 +32,26 @@ class Map(CMSPlugin):
         choices=settings.MAP_TEMPLATES,
         default=settings.MAP_DEFAULT_TEMPLATE,
     )
-    
+
+    def copy_relations(self, oldinstance):
+        # Before copying related objects from the old instance, the ones
+        # on the current one need to be deleted. Otherwise, duplicates may
+        # appear on the public version of the page
+        # Reference: https://docs.django-cms.org/en/latest/how_to/custom_plugins.html#handling-relations
+        self.positions.all().delete()
+
+        for positions in oldinstance.positions.all():
+            # instance.pk = None; instance.pk.save() is the slightly odd but
+            # standard Django way of copying a saved model instance
+            positions.pk = None
+            positions.relatedMap = self
+            positions.save()
+
     class Meta:
         verbose_name = _("Map")
         verbose_name_plural = _("Map")
 
+
 class MapPosition(models.Model):
     relatedMap = models.ForeignKey(Map, related_name="positions", on_delete=models.CASCADE)
     region = models.CharField(max_length=60, null=True, blank=True)
@@ -49,8 +64,8 @@ class MapPosition(models.Model):
     class Meta:
         verbose_name_plural = _('Positions')
         verbose_name = _('Positions')
-    
+
     def __str__(self):
         representative = self.name if self.name else "#" + str(self.id)
-        return representative + " | Map:" + str(self.relatedMap.id) 
-    
+        return representative + " | Map:" + str(self.relatedMap.id)
+
